@@ -1,5 +1,5 @@
 /******************************************************************************\
- * Copyright (c) 2004-2020
+ * Copyright (c) 2004-2022
  *
  * Author(s):
  *  Volker Fischer
@@ -177,14 +177,14 @@ CChannelFader::CChannelFader ( QWidget* pNW ) :
     QString strFaderText = "<b>" + tr ( "Fader Tag" ) + ":</b> " +
                            tr ( "The fader tag "
                                 "identifies the connected client. The tag name, a picture of your "
-                                "instrument and the flag of your country can be set in the main window." );
+                                "instrument and the flag of your location can be set in the main window." );
 
     plblInstrument->setWhatsThis ( strFaderText );
     plblInstrument->setAccessibleName ( tr ( "Mixer channel instrument picture" ) );
     plblLabel->setWhatsThis ( strFaderText );
     plblLabel->setAccessibleName ( tr ( "Mixer channel label (fader tag)" ) );
     plblCountryFlag->setWhatsThis ( strFaderText );
-    plblCountryFlag->setAccessibleName ( tr ( "Mixer channel country flag" ) );
+    plblCountryFlag->setAccessibleName ( tr ( "Mixer channel country/region flag" ) );
 
     // Connections -------------------------------------------------------------
     QObject::connect ( pFader, &QSlider::valueChanged, this, &CChannelFader::OnLevelValueChanged );
@@ -219,28 +219,24 @@ void CChannelFader::SetGUIDesign ( const EGUIDesign eNewDesign )
 
         pLabelGrid->addWidget ( plblLabel, 0, Qt::AlignVCenter ); // label next to icons
         pLabelInstBox->setMinimumHeight ( 52 );                   // maximum height of the instrument+flag pictures
-        pFader->setMinimumHeight ( 120 ); // if this value is too small, the fader might not be movable with the mouse for fancy skin (#292)
         pPan->setFixedSize ( 50, 50 );
         pPanLabel->setText ( tr ( "PAN" ) );
         pcbMute->setText ( tr ( "MUTE" ) );
         pcbSolo->setText ( tr ( "SOLO" ) );
-        strGroupBaseText = tr ( "GRP" );
-        plbrChannelLevel->SetLevelMeterType ( CLevelMeter::MT_LED );
+        strGroupBaseText  = tr ( "GRP" );
         iInstrPicMaxWidth = INVALID_INDEX; // no instrument picture scaling
         break;
 
     case GD_SLIMFADER:
         pLabelPictGrid->addWidget ( plblLabel, 0, Qt::AlignHCenter ); // label below icons
         pLabelInstBox->setMinimumHeight ( 130 );                      // maximum height of the instrument+flag+label
-        pFader->setMinimumHeight ( 85 );
         pPan->setFixedSize ( 28, 28 );
         pFader->setTickPosition ( QSlider::NoTicks );
         pFader->setStyleSheet ( "" );
         pPanLabel->setText ( tr ( "Pan" ) );
         pcbMute->setText ( tr ( "M" ) );
         pcbSolo->setText ( tr ( "S" ) );
-        strGroupBaseText = tr ( "G" );
-        plbrChannelLevel->SetLevelMeterType ( CLevelMeter::MT_SLIM_BAR );
+        strGroupBaseText  = tr ( "G" );
         iInstrPicMaxWidth = 18; // scale instrument picture to avoid enlarging the width by the picture
         break;
 
@@ -250,13 +246,11 @@ void CChannelFader::SetGUIDesign ( const EGUIDesign eNewDesign )
         pFader->setStyleSheet ( "" );
         pLabelGrid->addWidget ( plblLabel, 0, Qt::AlignVCenter ); // label next to icons
         pLabelInstBox->setMinimumHeight ( 52 );                   // maximum height of the instrument+flag pictures
-        pFader->setMinimumHeight ( 85 );
         pPan->setFixedSize ( 50, 50 );
         pPanLabel->setText ( tr ( "Pan" ) );
         pcbMute->setText ( tr ( "Mute" ) );
         pcbSolo->setText ( tr ( "Solo" ) );
-        strGroupBaseText = tr ( "Grp" );
-        plbrChannelLevel->SetLevelMeterType ( CLevelMeter::MT_BAR );
+        strGroupBaseText  = tr ( "Grp" );
         iInstrPicMaxWidth = INVALID_INDEX; // no instrument picture scaling
         break;
     }
@@ -268,6 +262,45 @@ void CChannelFader::SetGUIDesign ( const EGUIDesign eNewDesign )
     SetChannelInfos ( cReceivedChanInfo );
 }
 
+void CChannelFader::SetMeterStyle ( const EMeterStyle eNewMeterStyle )
+{
+    eMeterStyle = eNewMeterStyle;
+
+    switch ( eNewMeterStyle )
+    {
+    case MT_BAR_NARROW:
+        plbrChannelLevel->SetLevelMeterType ( CLevelMeter::MT_BAR_NARROW );
+        // Fader height controls the distribution of the LEDs, if the value is too small the fader might not be movable
+        pFader->setMinimumHeight ( 85 );
+        break;
+
+    case MT_BAR_WIDE:
+        plbrChannelLevel->SetLevelMeterType ( CLevelMeter::MT_BAR_WIDE );
+        // Fader height controls the distribution of the LEDs, if the value is too small the fader might not be movable
+        pFader->setMinimumHeight ( 120 );
+        break;
+
+    case MT_LED_ROUND_SMALL:
+        plbrChannelLevel->SetLevelMeterType ( CLevelMeter::MT_LED_ROUND_SMALL );
+        // Fader height controls the distribution of the LEDs, if the value is too small the fader might not be movable
+        pFader->setMinimumHeight ( 85 );
+        break;
+
+    case MT_LED_ROUND_BIG:
+        plbrChannelLevel->SetLevelMeterType ( CLevelMeter::MT_LED_ROUND_BIG );
+        // Fader height controls the distribution of the LEDs, if the value is too small the fader might not be movable
+        pFader->setMinimumHeight ( 162 );
+        break;
+
+    default:
+        // reset style sheet and set original parameters
+        plbrChannelLevel->SetLevelMeterType ( CLevelMeter::MT_LED_STRIPE );
+        // Fader height controls the distribution of the LEDs, if the value is too small the fader might not be movable
+        pFader->setMinimumHeight ( 120 );
+        break;
+    }
+}
+
 void CChannelFader::SetDisplayChannelLevel ( const bool eNDCL ) { plbrChannelLevel->setHidden ( !eNDCL ); }
 
 bool CChannelFader::GetDisplayChannelLevel() { return !plbrChannelLevel->isHidden(); }
@@ -643,7 +676,9 @@ void CChannelFader::SetChannelInfos ( const CChannelInfo& cChanInfo )
 
     // Label text --------------------------------------------------------------
 
-    QString strModText = cChanInfo.strName;
+    QString             strModText = cChanInfo.strName;
+    QTextBoundaryFinder tbfName ( QTextBoundaryFinder::Grapheme, cChanInfo.strName );
+    int                 iBreakPos;
 
     // apply break position and font size depending on the selected design
     if ( eDesign == GD_SLIMFADER )
@@ -652,10 +687,7 @@ void CChannelFader::SetChannelInfos ( const CChannelInfo& cChanInfo )
         plblLabel->setStyleSheet ( "QLabel { color: black; }" );
 
         // break at every 4th character
-        for ( int iInsPos = 4; iInsPos <= strModText.size() - 1; iInsPos += 4 + 1 )
-        {
-            strModText.insert ( iInsPos, "\n" );
-        }
+        iBreakPos = 4;
     }
     else
     {
@@ -663,11 +695,20 @@ void CChannelFader::SetChannelInfos ( const CChannelInfo& cChanInfo )
         plblLabel->setStyleSheet ( "QLabel { color: black; font: bold; }" );
 
         // break text at predefined position
-        const int iBreakPos = MAX_LEN_FADER_TAG / 2;
+        iBreakPos = MAX_LEN_FADER_TAG / 2;
+    }
 
-        if ( strModText.length() > iBreakPos )
+    int iInsPos     = iBreakPos;
+    int iCount      = 0;
+    int iLineNumber = 0;
+    while ( tbfName.toNextBoundary() != -1 )
+    {
+        ++iCount;
+        if ( iCount == iInsPos )
         {
-            strModText.insert ( iBreakPos, QString ( "\n" ) );
+            strModText.insert ( tbfName.position() + iLineNumber, QString ( "\n" ) );
+            iLineNumber++;
+            iInsPos += iBreakPos;
         }
     }
 
@@ -952,6 +993,15 @@ void CAudioMixerBoard::SetGUIDesign ( const EGUIDesign eNewDesign )
     }
 }
 
+void CAudioMixerBoard::SetMeterStyle ( const EMeterStyle eNewMeterStyle )
+{
+    // apply GUI design to child GUI controls
+    for ( int i = 0; i < MAX_NUM_CHANNELS; i++ )
+    {
+        vecpChanFader[i]->SetMeterStyle ( eNewMeterStyle );
+    }
+}
+
 void CAudioMixerBoard::SetDisplayPans ( const bool eNDP )
 {
     bDisplayPans = eNDP;
@@ -1020,9 +1070,15 @@ void CAudioMixerBoard::ChangeFaderOrder ( const EChSortType eChSortType )
     // create a pair list of lower strings and fader ID for each channel
     QList<QPair<QString, int>> PairList;
     int                        iNumVisibleFaders = 0;
+    int                        iMyFader          = -1;
 
     for ( int i = 0; i < MAX_NUM_CHANNELS; i++ )
     {
+        if ( vecpChanFader[i]->GetIsMyOwnFader() )
+        {
+            iMyFader = i;
+        }
+
         if ( eChSortType == ST_BY_NAME )
         {
             PairList << QPair<QString, int> ( vecpChanFader[i]->GetReceivedName().toLower(), i );
@@ -1067,6 +1123,19 @@ void CAudioMixerBoard::ChangeFaderOrder ( const EChSortType eChSortType )
     // sort the channels according to the first of the pair
     std::stable_sort ( PairList.begin(), PairList.end() );
 
+    // move my fader to first position
+    if ( pSettings->bOwnFaderFirst )
+    {
+        for ( int i = 0; i < MAX_NUM_CHANNELS; i++ )
+        {
+            if ( iMyFader == PairList[i].second )
+            {
+                PairList.move ( i, 0 );
+                break;
+            }
+        }
+    }
+
     // we want to distribute iNumVisibleFaders across the first row, then the next, etc
     // up to iNumMixerPanelRows.  So row wants to start at 0 until we get to some number,
     // then increase, where "some number" means we get no more than iNumMixerPanelRows.
