@@ -1,5 +1,5 @@
 /******************************************************************************\
- * Copyright (c) 2004-2020
+ * Copyright (c) 2004-2022
  *
  * Author(s):
  *  Volker Fischer
@@ -134,6 +134,9 @@ public:
     EGUIDesign GetGUIDesign() const { return eGUIDesign; }
     void       SetGUIDesign ( const EGUIDesign eNGD ) { eGUIDesign = eNGD; }
 
+    EMeterStyle GetMeterStyle() const { return eMeterStyle; }
+    void        SetMeterStyle ( const EMeterStyle eNMT ) { eMeterStyle = eNMT; }
+
     EAudioQuality GetAudioQuality() const { return eAudioQuality; }
     void          SetAudioQuality ( const EAudioQuality eNAudioQuality );
 
@@ -344,8 +347,9 @@ protected:
     int iMonoBlockSizeSam;
     int iStereoBlockSizeSam;
 
-    EGUIDesign eGUIDesign;
-    bool       bEnableOPUS64;
+    EGUIDesign  eGUIDesign;
+    EMeterStyle eMeterStyle;
+    bool        bEnableOPUS64;
 
     bool   bJitterBufferOK;
     bool   bEnableIPv6;
@@ -389,6 +393,7 @@ protected slots:
     void OnControllerInPanValue ( int iChannelIdx, int iValue );
     void OnControllerInFaderIsSolo ( int iChannelIdx, bool bIsSolo );
     void OnControllerInFaderIsMute ( int iChannelIdx, bool bIsMute );
+    void OnControllerInMuteMyself ( bool bMute );
     void OnClientIDReceived ( int iChanID );
 
 signals:
@@ -419,4 +424,5 @@ signals:
     void ControllerInPanValue ( int iChannelIdx, int iValue );
     void ControllerInFaderIsSolo ( int iChannelIdx, bool bIsSolo );
     void ControllerInFaderIsMute ( int iChannelIdx, bool bIsMute );
+    void ControllerInMuteMyself ( bool bMute );
 };
