@@ -1,5 +1,5 @@
 /******************************************************************************\
- * Copyright (c) 2004-2020
+ * Copyright (c) 2004-2022
  *
  * Author(s):
  *  Volker Fischer
@@ -65,7 +65,7 @@ public:
 protected:
     void    UpdateJitterBufferFrame();
     void    UpdateSoundCardFrame();
-    void    UpdateCustomCentralServerComboBox();
+    void    UpdateDirectoryServerComboBox();
     void    UpdateAudioFaderSlider();
     QString GenSndCrdBufferDelayString ( const int iFrameSize, const QString strAddText = "" );
 
@@ -83,7 +83,7 @@ public slots:
     void OnAutoJitBufStateChanged ( int value );
     void OnEnableOPUS64StateChanged ( int value );
     void OnFeedbackDetectionChanged ( int value );
-    void OnCentralServerAddressEditingFinished();
+    void OnCustomDirectoriesEditingFinished();
     void OnNewClientLevelEditingFinished() { pSettings->iNewClientFaderLevel = edtNewClientLevel->text().toInt(); }
     void OnInputBoostChanged();
     void OnSndCrdBufferDelayButtonGroupClicked ( QAbstractButton* button );
@@ -95,7 +95,7 @@ public slots:
     void OnAudioChannelsActivated ( int iChanIdx );
     void OnAudioQualityActivated ( int iQualityIdx );
     void OnGUIDesignActivated ( int iDesignIdx );
-    void OnDriverSetupClicked();
+    void OnMeterStyleActivated ( int iMeterStyleIdx );
     void OnLanguageChanged ( QString strLanguage ) { pSettings->strLanguage = strLanguage; }
     void OnAliasTextChanged ( const QString& strNewName );
     void OnInstrumentActivated ( int iCntryListItem );
@@ -106,9 +106,15 @@ public slots:
     void OnMakeTabChange ( int iTabIdx );
     void OnAudioPanValueChanged ( int value );
 
+#if defined( _WIN32 ) && !defined( WITH_JACK )
+    // Only include this slot for Windows when JACK is NOT used
+    void OnDriverSetupClicked();
+#endif
+
 signals:
     void GUIDesignChanged();
+    void MeterStyleChanged();
     void AudioChannelsChanged();
-    void CustomCentralServerAddrChanged();
+    void CustomDirectoriesChanged();
     void NumMixerPanelRowsChanged ( int value );
 };
