@@ -1,5 +1,5 @@
 /******************************************************************************\
- * Copyright (c) 2004-2020
+ * Copyright (c) 2004-2022
  *
  * Author(s):
  *  Volker Fischer
@@ -218,7 +218,7 @@ CServer::CServer ( const int          iNewMaxNumChan,
                    const quint16      iPortNumber,
                    const quint16      iQosNumber,
                    const QString&     strHTMLStatusFileName,
-                   const QString&     strCentralServer,
+                   const QString&     strDirectoryServer,
                    const QString&     strServerListFileName,
                    const QString&     strServerInfo,
                    const QString&     strServerListFilter,
@@ -243,7 +243,7 @@ CServer::CServer ( const int          iNewMaxNumChan,
     strServerHTMLFileListName ( strHTMLStatusFileName ),
     HighPrecisionTimer ( bNUseDoubleSystemFrameSize ),
     ServerListManager ( iPortNumber,
-                        strCentralServer,
+                        strDirectoryServer,
                         strServerListFileName,
                         strServerInfo,
                         strServerPublicIP,
@@ -685,9 +685,9 @@ void CServer::OnAboutToQuit()
     Stop();
 
     // if server was registered at the directory server, unregister on shutdown
-    if ( GetServerListEnabled() )
+    if ( GetServerRegistered() )
     {
-        UnregisterSlaveServer();
+        Unregister();
     }
 
     if ( bWriteStatusHTMLFile )
@@ -1041,7 +1041,7 @@ void CServer::DecodeReceiveData ( const int iChanCnt, const int iNumClients )
         // get current number of OPUS coded bytes
         const int iCeltNumCodedBytes = vecChannels[iCurChanID].GetCeltNumCodedBytes();
 
-        for ( size_t iB = 0; iB < (size_t) vecNumFrameSizeConvBlocks[iChanCnt]; iB++ )
+        for ( int iB = 0; iB < vecNumFrameSizeConvBlocks[iChanCnt]; iB++ )
         {
             // get data
             const EGetDataStat eGetStat = vecChannels[iCurChanID].GetData ( vecvecbyCodedData[iChanCnt], iCeltNumCodedBytes );
@@ -1081,10 +1081,12 @@ void CServer::DecodeReceiveData ( const int iChanCnt, const int iNumClients )
             // OPUS decode received data stream
             if ( CurOpusDecoder != nullptr )
             {
+                const int iOffset = iB * SYSTEM_FRAME_SIZE_SAMPLES * vecNumAudioChannels[iChanCnt];
+
                 iUnused = opus_custom_decode ( CurOpusDecoder,
                                                pCurCodedData,
                                                iCeltNumCodedBytes,
-                                               &vecvecsData[iChanCnt][iB * SYSTEM_FRAME_SIZE_SAMPLES * vecNumAudioChannels[iChanCnt]],
+                                               &vecvecsData[iChanCnt][iOffset],
                                                iClientFrameSizeSamples );
             }
         }
@@ -1354,10 +1356,12 @@ void CServer::MixEncodeTransmitData ( const int iChanCnt, const int iNumClients
 opus_custom_encoder_ctl ( pCurOpusEncoder, OPUS_SET_BITRATE ( CalcBitRateBitsPerSecFromCodedBytes ( iCeltNumCodedBytes, iClientFrameSizeSamples ) ) );
             // clang-format on
 
-            for ( size_t iB = 0; iB < (size_t) vecNumFrameSizeConvBlocks[iChanCnt]; iB++ )
+            for ( int iB = 0; iB < vecNumFrameSizeConvBlocks[iChanCnt]; iB++ )
             {
+                const int iOffset = iB * SYSTEM_FRAME_SIZE_SAMPLES * vecNumAudioChannels[iChanCnt];
+
                 iUnused = opus_custom_encode ( pCurOpusEncoder,
-                                               &vecsSendData[iB * SYSTEM_FRAME_SIZE_SAMPLES * vecNumAudioChannels[iChanCnt]],
+                                               &vecsSendData[iOffset],
                                                iClientFrameSizeSamples,
                                                &vecvecbyCodedData[iChanCnt][0],
                                                iCeltNumCodedBytes );
@@ -1502,7 +1506,7 @@ int CServer::FindChannel ( const CHostAddress& CheckAddr, const bool bAllowNew )
             return vecChannelOrder[t];
         }
 
-        if ( cmp < 0 )
+        if ( cmp > 0 )
         {
             l = t + 1;
         }
@@ -1574,13 +1578,14 @@ void CServer::FreeChannel ( const int iCurChanID )
         {
             --iCurNumChannels;
 
-            // move channel IDs down by one starting at the bottom and working up
-            while ( i < iCurNumChannels )
+            // move channel IDs down by one starting at the freed channel and working up the active channels
+            // and then the free channels until its position in the free list is reached
+            while ( i < iCurNumChannels || ( i + 1 < iMaxNumChannels && vecChannelOrder[i + 1] < iCurChanID ) )
             {
                 int j              = i++;
                 vecChannelOrder[j] = vecChannelOrder[i];
             }
-            // put deleted channel at the end ready for re-use
+            // put deleted channel in the vacated position ready for re-use
             vecChannelOrder[i] = iCurChanID;
 
             // DumpChannels ( __FUNCTION__ );
@@ -1609,7 +1614,7 @@ void CServer::DumpChannels ( const QString& title )
     }
 }
 
-void CServer::OnProtcolCLMessageReceived ( int iRecID, CVector<uint8_t> vecbyMesBodyData, CHostAddress RecHostAddr )
+void CServer::OnProtocolCLMessageReceived ( int iRecID, CVector<uint8_t> vecbyMesBodyData, CHostAddress RecHostAddr )
 {
     QMutexLocker locker ( &Mutex );
 
@@ -1617,7 +1622,7 @@ void CServer::OnProtcolCLMessageReceived ( int iRecID, CVector<uint8_t> vecbyMes
     ConnLessProtocol.ParseConnectionLessMessageBody ( vecbyMesBodyData, iRecID, RecHostAddr );
 }
 
-void CServer::OnProtcolMessageReceived ( int iRecCounter, int iRecID, CVector<uint8_t> vecbyMesBodyData, CHostAddress RecHostAddr )
+void CServer::OnProtocolMessageReceived ( int iRecCounter, int iRecID, CVector<uint8_t> vecbyMesBodyData, CHostAddress RecHostAddr )
 {
     QMutexLocker locker ( &Mutex );
 
@@ -1627,7 +1632,7 @@ void CServer::OnProtcolMessageReceived ( int iRecCounter, int iRecID, CVector<ui
     // if the channel exists, apply the protocol message to the channel
     if ( iCurChanID != INVALID_CHANNEL_ID )
     {
-        vecChannels[iCurChanID].PutProtcolData ( iRecCounter, iRecID, vecbyMesBodyData, RecHostAddr );
+        vecChannels[iCurChanID].PutProtocolData ( iRecCounter, iRecID, vecbyMesBodyData, RecHostAddr );
     }
 }
 
