@@ -1,5 +1,5 @@
 /******************************************************************************\
- * Copyright (c) 2004-2020
+ * Copyright (c) 2004-2022
  *
  * Author(s):
  *  Volker Fischer
@@ -29,15 +29,21 @@ CServerDlg::CServerDlg ( CServer* pNServP, CServerSettings* pNSetP, const bool b
     CBaseDlg ( parent, Qt::Window ), // use Qt::Window to get min/max window buttons
     pServer ( pNServP ),
     pSettings ( pNSetP ),
-    BitmapSystemTrayInactive ( QString::fromUtf8 ( ":/png/LEDs/res/CLEDGreyArrow.png" ) ),
-    BitmapSystemTrayActive ( QString::fromUtf8 ( ":/png/LEDs/res/CLEDGreenArrow.png" ) )
+    BitmapSystemTrayInactive ( QString::fromUtf8 ( ":/png/main/res/servertrayiconinactive.png" ) ),
+    BitmapSystemTrayActive ( QString::fromUtf8 ( ":/png/main/res/servertrayiconactive.png" ) )
 {
     // check if system tray icon can be used
-    bSystemTrayIconAvaialbe = SystemTrayIcon.isSystemTrayAvailable();
+    bSystemTrayIconAvailable = SystemTrayIcon.isSystemTrayAvailable();
 
     setupUi ( this );
 
+    // set window title
+    setWindowTitle ( tr ( "%1 Server", "%1 is the name of the main application" ).arg ( APP_NAME ) );
+
     // Add help text to controls -----------------------------------------------
+
+    // Tab: Server setup
+
     // client list
     lvwClients->setWhatsThis ( "<b>" + tr ( "Client List" ) + ":</b> " +
                                tr ( "The client list shows all clients which are currently connected to this "
@@ -46,16 +52,6 @@ CServerDlg::CServerDlg ( CServer* pNServP, CServerSettings* pNSetP, const bool b
 
     lvwClients->setAccessibleName ( tr ( "Connected clients list view" ) );
 
-    // start minimized on operating system start
-    chbStartOnOSStart->setWhatsThis ( "<b>" +
-                                      tr ( "Start Minimized on Operating "
-                                           "System Start" ) +
-                                      ":</b> " +
-                                      tr ( "If the start minimized on operating system start "
-                                           "check box is checked, the server will be "
-                                           "started when the operating system starts up and is automatically "
-                                           "minimized to a system task bar icon." ) );
-
     // Make My Server Public flag
     chbRegisterServer->setWhatsThis ( "<b>" + tr ( "Make My Server Public" ) + ":</b> " +
                                       tr ( "If the Make My Server Public check box is checked, this server registers "
@@ -65,24 +61,15 @@ CServerDlg::CServerDlg ( CServer* pNServP, CServerSettings* pNSetP, const bool b
                                            "to make sure that all servers in the connect dialog server list are "
                                            "actually available." ) );
 
-    // register server status label
+    // server registration status label
     lblRegSvrStatus->setWhatsThis ( "<b>" + tr ( "Register Server Status" ) + ":</b> " +
-                                    tr ( "If the Make My Server Public check box is checked, this will show "
+                                    tr ( "If the Register Server check box is checked, this will show "
                                          "whether registration with the directory server is successful. If the "
                                          "registration failed, please choose another server list." ) );
 
-    // custom directory server address
-    QString strCentrServAddr = "<b>" + tr ( "Custom Directory Server Address" ) + ":</b> " +
-                               tr ( "The custom directory server address is the IP address or URL of the directory "
-                                    "server at which the server list of the connection dialog is managed." );
-
-    lblCentralServerAddress->setWhatsThis ( strCentrServAddr );
-    edtCentralServerAddress->setWhatsThis ( strCentrServAddr );
-    edtCentralServerAddress->setAccessibleName ( tr ( "Directory server address line edit" ) );
-
-    cbxCentServAddrType->setWhatsThis ( "<b>" + tr ( "Server List Selection" ) + ":</b> " +
-                                        tr ( "Selects the server list (i.e. directory server address) in which your server will be added." ) );
-    cbxCentServAddrType->setAccessibleName ( tr ( "Server list selection combo box" ) );
+    cbxDirectoryType->setWhatsThis ( "<b>" + tr ( "Server List Selection" ) + ":</b> " +
+                                     tr ( "Selects the server list (i.e. directory server address) in which your server will be added." ) );
+    cbxDirectoryType->setAccessibleName ( tr ( "Server list selection combo box" ) );
 
     // server name
     QString strServName = "<b>" + tr ( "Server Name" ) + ":</b> " +
@@ -116,25 +103,6 @@ CServerDlg::CServerDlg ( CServer* pNServP, CServerSettings* pNSetP, const bool b
 
     cbxLocationCountry->setAccessibleName ( tr ( "Combo box for location of this server" ) );
 
-    // recording directory
-    pbtRecordingDir->setAccessibleName ( tr ( "Display dialog to select recording directory button" ) );
-    pbtRecordingDir->setWhatsThis ( "<b>" + tr ( "Main Recording Directory" ) + ":</b> " +
-                                    tr ( "Click the button to open the dialog that allows the main recording directory to be selected."
-                                         "The chosen value must exist and be writeable (allow creation of sub-directories "
-                                         "by the user Jamulus is running as). " ) );
-
-    edtRecordingDir->setAccessibleName ( tr ( "Main recording directory text box (read-only)" ) );
-    edtRecordingDir->setWhatsThis ( "<b>" + tr ( "Main Recording Directory" ) + ":</b> " +
-                                    tr ( "The current value of the main recording directory. "
-                                         "The chosen value must exist and be writeable (allow creation of sub-directories "
-                                         "by the user Jamulus is running as). "
-                                         "Click the button to open the dialog that allows the main recording directory to be selected." ) );
-
-    tbtClearRecordingDir->setAccessibleName ( tr ( "Clear the recording directory button" ) );
-    tbtClearRecordingDir->setWhatsThis ( "<b>" + tr ( "Clear Recording Directory" ) + ":</b> " +
-                                         tr ( "Click the button to clear the currently selected recording directory. "
-                                              "This will prevent recording until a new value is selected." ) );
-
     // enable recorder
     chbEnableRecorder->setAccessibleName ( tr ( "Checkbox to turn on or off server recording" ) );
     chbEnableRecorder->setWhatsThis ( "<b>" + tr ( "Enable Recorder" ) + ":</b> " +
@@ -152,11 +120,11 @@ CServerDlg::CServerDlg ( CServer* pNServP, CServerSettings* pNSetP, const bool b
     lblRecorderStatus->setWhatsThis (
         "<b>" + tr ( "Recorder Status" ) + ":</b> " + tr ( "Displays the current status of the recorder.  The following values are possible:" ) +
         "<dl>" + "<dt>" + SREC_NOT_INITIALISED + "</dt>" + "<dd>" + tr ( "No recording directory has been set or the value is not useable" ) +
-        "</dd>" + "<dt>" + SREC_NOT_ENABLED + "</dt>" + "<dd>" + tr ( "Recording has been switched off" )
+        "</dd>" + "<dt>" + SREC_NOT_ENABLED + "</dt>" + "<dd>"
 #ifdef _WIN32
-        + tr ( " by the UI checkbox" )
+        + tr ( "Recording has been switched off by the UI checkbox" )
 #else
-        + tr ( ", either by the UI checkbox or SIGUSR2 being received" )
+        + tr ( "Recording has been switched off, either by the UI checkbox or SIGUSR2 being received" )
 #endif
         + "</dd>" + "<dt>" + SREC_NOT_RECORDING + "</dt>" + "<dd>" + tr ( "There is no one connected to the server to record" ) + "</dd>" + "<dt>" +
         SREC_RECORDING + "</dt>" + "<dd>" + tr ( "The performers are being recorded to the specified session directory" ) + "</dd>" + "</dl>" +
@@ -174,8 +142,54 @@ CServerDlg::CServerDlg ( CServer* pNServP, CServerSettings* pNSetP, const bool b
                                       tr ( "A server welcome message text is displayed in the chat window if a "
                                            "musician enters the server. If no message is set, the server welcome is disabled." ) );
 
+    // Tab: options
+
+    // Interface Language
+    QString strWTLanguage = "<b>" + tr ( "Language" ) + ":</b> " + tr ( "Select the language to be used for the user interface." );
+    lblLanguage->setWhatsThis ( strWTLanguage );
+    cbxLanguage->setWhatsThis ( strWTLanguage );
+
+    cbxLanguage->setAccessibleName ( tr ( "Language combo box" ) );
+
+    // recording directory
+    pbtRecordingDir->setAccessibleName ( tr ( "Display dialog to select recording directory button" ) );
+    pbtRecordingDir->setWhatsThis ( "<b>" + tr ( "Main Recording Directory" ) + ":</b> " +
+                                    tr ( "Click the button to open the dialog that allows the main recording directory to be selected.  "
+                                         "The chosen value must exist and be writeable (allow creation of sub-directories "
+                                         "by the user Jamulus is running as)." ) );
+
+    edtRecordingDir->setAccessibleName ( tr ( "Main recording directory text box (read-only)" ) );
+    edtRecordingDir->setWhatsThis ( "<b>" + tr ( "Main Recording Directory" ) + ":</b> " +
+                                    tr ( "The current value of the main recording directory. "
+                                         "The chosen value must exist and be writeable (allow creation of sub-directories "
+                                         "by the user Jamulus is running as). "
+                                         "Click the button to open the dialog that allows the main recording directory to be selected." ) );
+
+    tbtClearRecordingDir->setAccessibleName ( tr ( "Clear the recording directory button" ) );
+    tbtClearRecordingDir->setWhatsThis ( "<b>" + tr ( "Clear Recording Directory" ) + ":</b> " +
+                                         tr ( "Click the button to clear the currently selected recording directory. "
+                                              "This will prevent recording until a new value is selected." ) );
+
+    // custom directory
+    QString strCustomDirectory = "<b>" + tr ( "Custom Directory" ) + ":</b> " +
+                                 tr ( "The custom directory is the IP address or URL of the directory "
+                                      "server at which the server list of the connection dialog is managed." );
+
+    lblCustomDirectory->setWhatsThis ( strCustomDirectory );
+    edtCustomDirectory->setWhatsThis ( strCustomDirectory );
+    edtCustomDirectory->setAccessibleName ( tr ( "Custom Directory line edit" ) );
+
+    // start minimized on operating system start
+    chbStartOnOSStart->setWhatsThis ( "<b>" + tr ( "Start Minimized on Operating System Start" ) + ":</b> " +
+                                      tr ( "If the start minimized on operating system start "
+                                           "check box is checked, the server will be "
+                                           "started when the operating system starts up and is automatically "
+                                           "minimized to a system task bar icon." ) );
+
+    // Application initialisation
+
     // init system tray icon
-    if ( bSystemTrayIconAvaialbe )
+    if ( bSystemTrayIconAvailable )
     {
         // prepare context menu to be added to the system tray icon
         pSystemTrayIconMenu = new QMenu ( this );
@@ -184,10 +198,10 @@ CServerDlg::CServerDlg ( CServer* pNServP, CServerSettings* pNSetP, const bool b
 
         pSystemTrayIconMenu->addSeparator();
 
-        pSystemTrayIconMenu->addAction ( tr ( "&Hide " ) + APP_NAME + tr ( " server" ), this, SLOT ( OnSysTrayMenuHide() ) );
+        pSystemTrayIconMenu->addAction ( tr ( "&Hide %1 server" ).arg ( APP_NAME ), this, SLOT ( OnSysTrayMenuHide() ) );
 
         pSystemTrayIconMenu->setDefaultAction (
-            pSystemTrayIconMenu->addAction ( tr ( "&Open " ) + APP_NAME + tr ( " server" ), this, SLOT ( OnSysTrayMenuOpen() ) ) );
+            pSystemTrayIconMenu->addAction ( tr ( "&Show %1 server" ).arg ( APP_NAME ), this, SLOT ( OnSysTrayMenuOpen() ) ) );
 
         SystemTrayIcon.setContextMenu ( pSystemTrayIconMenu );
 
@@ -200,12 +214,14 @@ CServerDlg::CServerDlg ( CServer* pNServP, CServerSettings* pNSetP, const bool b
     }
 
     // act on "start minimized" flag (note, this has to be done after setting
-    // the correct value for the system tray icon availablility)
+    // and acting on the correct value for the system tray icon availablility)
     if ( bStartMinimized )
     {
         showMinimized();
     }
 
+    // UI initialisation
+
     // set up list view for connected clients
     lvwClients->setColumnWidth ( 0, 170 ); // 170 //  IP:port
     lvwClients->setColumnWidth ( 1, 200 ); // 200 //  Name
@@ -229,20 +245,20 @@ lvwClients->setMinimumHeight ( 140 );
         vecpListViewItems[i]->setHidden ( true );
     }
 
-    // directory server address type combo box
-    cbxCentServAddrType->clear();
-    cbxCentServAddrType->addItem ( csCentServAddrTypeToString ( AT_DEFAULT ) );
-    cbxCentServAddrType->addItem ( csCentServAddrTypeToString ( AT_ANY_GENRE2 ) );
-    cbxCentServAddrType->addItem ( csCentServAddrTypeToString ( AT_ANY_GENRE3 ) );
-    cbxCentServAddrType->addItem ( csCentServAddrTypeToString ( AT_GENRE_ROCK ) );
-    cbxCentServAddrType->addItem ( csCentServAddrTypeToString ( AT_GENRE_JAZZ ) );
-    cbxCentServAddrType->addItem ( csCentServAddrTypeToString ( AT_GENRE_CLASSICAL_FOLK ) );
-    cbxCentServAddrType->addItem ( csCentServAddrTypeToString ( AT_GENRE_CHORAL ) );
-    cbxCentServAddrType->addItem ( csCentServAddrTypeToString ( AT_CUSTOM ) );
-    cbxCentServAddrType->setCurrentIndex ( static_cast<int> ( pServer->GetCentralServerAddressType() ) );
+    // directory type combo box
+    cbxDirectoryType->clear();
+    cbxDirectoryType->addItem ( DirectoryTypeToString ( AT_DEFAULT ) );
+    cbxDirectoryType->addItem ( DirectoryTypeToString ( AT_ANY_GENRE2 ) );
+    cbxDirectoryType->addItem ( DirectoryTypeToString ( AT_ANY_GENRE3 ) );
+    cbxDirectoryType->addItem ( DirectoryTypeToString ( AT_GENRE_ROCK ) );
+    cbxDirectoryType->addItem ( DirectoryTypeToString ( AT_GENRE_JAZZ ) );
+    cbxDirectoryType->addItem ( DirectoryTypeToString ( AT_GENRE_CLASSICAL_FOLK ) );
+    cbxDirectoryType->addItem ( DirectoryTypeToString ( AT_GENRE_CHORAL ) );
+    cbxDirectoryType->addItem ( DirectoryTypeToString ( AT_CUSTOM ) );
+    cbxDirectoryType->setCurrentIndex ( static_cast<int> ( pServer->GetDirectoryType() ) );
 
     // custom directory server address
-    edtCentralServerAddress->setText ( pServer->GetServerListCentralServerAddress() );
+    edtCustomDirectory->setText ( pServer->GetDirectoryAddress() );
 
     // update server name line edit
     edtServerName->setText ( pServer->GetServerName() );
@@ -272,7 +288,7 @@ lvwClients->setMinimumHeight ( 140 );
     cbxLocationCountry->setCurrentIndex ( cbxLocationCountry->findData ( static_cast<int> ( pServer->GetServerCountry() ) ) );
 
     // update register server check box
-    if ( pServer->GetServerListEnabled() )
+    if ( pServer->GetServerRegistered() )
     {
         chbRegisterServer->setCheckState ( Qt::Checked );
     }
@@ -281,6 +297,23 @@ lvwClients->setMinimumHeight ( 140 );
         chbRegisterServer->setCheckState ( Qt::Unchecked );
     }
 
+    // Recorder controls
+    chbEnableRecorder->setChecked ( pServer->GetRecordingEnabled() );
+    edtCurrentSessionDir->setText ( "" );
+    pbtNewRecording->setAutoDefault ( false );
+
+    // setup welcome message GUI control
+    tedWelcomeMessage->setPlaceholderText ( tr ( "Type a message here. If no message is set, the server welcome is disabled." ) );
+    tedWelcomeMessage->setText ( pServer->GetWelcomeMessage() );
+
+    // language combo box (corrects the setting if language not found)
+    cbxLanguage->Init ( pSettings->strLanguage );
+
+    // recorder options
+    pbtRecordingDir->setAutoDefault ( false );
+    edtRecordingDir->setText ( pServer->GetRecordingDir() );
+    tbtClearRecordingDir->setText ( u8"\u232B" );
+
     // update start minimized check box (only available for Windows)
 #ifndef _WIN32
     chbStartOnOSStart->setVisible ( false );
@@ -311,24 +344,6 @@ lvwClients->setMinimumHeight ( 140 );
         chbEnableDelayPanning->setCheckState ( Qt::Unchecked );
     }
 
-    // Recorder controls
-    chbEnableRecorder->setChecked ( pServer->GetRecordingEnabled() );
-    edtCurrentSessionDir->setText ( "" );
-    pbtNewRecording->setAutoDefault ( false );
-    pbtRecordingDir->setAutoDefault ( false );
-    edtRecordingDir->setText ( pServer->GetRecordingDir() );
-    tbtClearRecordingDir->setText ( u8"\u232B" );
-
-    UpdateRecorderStatus ( QString::null );
-
-    // language combo box (corrects the setting if language not found)
-    cbxLanguage->Init ( pSettings->strLanguage );
-
-    // setup welcome message GUI control
-    tedWelcomeMessage->setPlaceholderText ( tr ( "Type a message here. If no message is set, the server welcome is disabled." ) );
-
-    tedWelcomeMessage->setText ( pServer->GetWelcomeMessage() );
-
     // prepare update check info label (invisible by default)
     lblUpdateCheck->setOpenExternalLinks ( true ); // enables opening a web browser if one clicks on a html link
     lblUpdateCheck->setText ( "<font color=\"red\"><b>" + APP_UPGRADE_AVAILABLE_MSG_TEXT.arg ( APP_NAME ).arg ( VERSION ) + "</b></font>" );
@@ -337,8 +352,7 @@ lvwClients->setMinimumHeight ( 140 );
     // update GUI dependencies
     UpdateGUIDependencies();
 
-    // set window title
-    setWindowTitle ( tr ( "%1 Server", "%1 is the name of the main application" ).arg ( APP_NAME ) );
+    UpdateRecorderStatus ( QString::null );
 
     // View menu  --------------------------------------------------------------
     QMenu* pViewMenu = new QMenu ( tr ( "&Window" ), this );
@@ -365,38 +379,37 @@ lvwClients->setMinimumHeight ( 140 );
     // check boxes
     QObject::connect ( chbRegisterServer, &QCheckBox::stateChanged, this, &CServerDlg::OnRegisterServerStateChanged );
 
-    QObject::connect ( chbStartOnOSStart, &QCheckBox::stateChanged, this, &CServerDlg::OnStartOnOSStartStateChanged );
-
     QObject::connect ( chbEnableRecorder, &QCheckBox::stateChanged, this, &CServerDlg::OnEnableRecorderStateChanged );
 
-    // delay panning
+    QObject::connect ( chbStartOnOSStart, &QCheckBox::stateChanged, this, &CServerDlg::OnStartOnOSStartStateChanged );
+
     QObject::connect ( chbEnableDelayPanning, &QCheckBox::stateChanged, this, &CServerDlg::OnEnableDelayPanningStateChanged );
 
     // line edits
-    QObject::connect ( edtCentralServerAddress, &QLineEdit::editingFinished, this, &CServerDlg::OnCentralServerAddressEditingFinished );
-
     QObject::connect ( edtServerName, &QLineEdit::textChanged, this, &CServerDlg::OnServerNameTextChanged );
 
     QObject::connect ( edtLocationCity, &QLineEdit::textChanged, this, &CServerDlg::OnLocationCityTextChanged );
 
+    QObject::connect ( edtCustomDirectory, &QLineEdit::editingFinished, this, &CServerDlg::OnCustomDirectoryEditingFinished );
+
     // combo boxes
+    QObject::connect ( cbxDirectoryType,
+                       static_cast<void ( QComboBox::* ) ( int )> ( &QComboBox::activated ),
+                       this,
+                       &CServerDlg::OnDirectoryTypeActivated );
+
     QObject::connect ( cbxLocationCountry,
                        static_cast<void ( QComboBox::* ) ( int )> ( &QComboBox::activated ),
                        this,
                        &CServerDlg::OnLocationCountryActivated );
 
-    QObject::connect ( cbxCentServAddrType,
-                       static_cast<void ( QComboBox::* ) ( int )> ( &QComboBox::activated ),
-                       this,
-                       &CServerDlg::OnCentServAddrTypeActivated );
-
     QObject::connect ( cbxLanguage, &CLanguageComboBox::LanguageChanged, this, &CServerDlg::OnLanguageChanged );
 
     // push buttons
-    QObject::connect ( pbtRecordingDir, &QPushButton::released, this, &CServerDlg::OnRecordingDirClicked );
-
     QObject::connect ( pbtNewRecording, &QPushButton::released, this, &CServerDlg::OnNewRecordingClicked );
 
+    QObject::connect ( pbtRecordingDir, &QPushButton::released, this, &CServerDlg::OnRecordingDirClicked );
+
     // tool buttons
     QObject::connect ( tbtClearRecordingDir, &QToolButton::released, this, &CServerDlg::OnClearRecordingDirClicked );
 
@@ -467,12 +480,12 @@ void CServerDlg::OnRegisterServerStateChanged ( int value )
     const bool bRegState = ( value == Qt::Checked );
 
     // apply new setting to the server and update it
-    pServer->SetServerListEnabled ( bRegState );
+    pServer->SetServerRegistered ( bRegState );
 
-    // if registering is disabled, unregister slave server
+    // if registering is disabled, unregister server
     if ( !bRegState )
     {
-        pServer->UnregisterSlaveServer();
+        pServer->Unregister();
     }
 
     pServer->UpdateServerList();
@@ -481,10 +494,10 @@ void CServerDlg::OnRegisterServerStateChanged ( int value )
     UpdateGUIDependencies();
 }
 
-void CServerDlg::OnCentralServerAddressEditingFinished()
+void CServerDlg::OnCustomDirectoryEditingFinished()
 {
     // apply new setting to the server and update it
-    pServer->SetServerListCentralServerAddress ( edtCentralServerAddress->text() );
+    pServer->SetDirectoryAddress ( edtCustomDirectory->text() );
 
     pServer->UpdateServerList();
 }
@@ -529,11 +542,11 @@ void CServerDlg::OnLocationCountryActivated ( int iCntryListItem )
     pServer->UpdateServerList();
 }
 
-void CServerDlg::OnCentServAddrTypeActivated ( int iTypeIdx )
+void CServerDlg::OnDirectoryTypeActivated ( int iTypeIdx )
 {
 
     // apply new setting to the server and update it
-    pServer->SetCentralServerAddressType ( static_cast<ECSAddType> ( iTypeIdx ) );
+    pServer->SetDirectoryType ( static_cast<EDirectoryType> ( iTypeIdx ) );
     pServer->UpdateServerList();
 
     // update GUI dependencies
@@ -669,13 +682,13 @@ void CServerDlg::OnTimer()
 void CServerDlg::UpdateGUIDependencies()
 {
     // get the states which define the GUI dependencies from the server
-    const bool          bCurSerListEnabled = pServer->GetServerListEnabled();
-    const ESvrRegStatus eSvrRegStatus      = pServer->GetSvrRegStatus();
+    const bool          bIsRegistered = pServer->GetServerRegistered();
+    const ESvrRegStatus eSvrRegStatus = pServer->GetSvrRegStatus();
 
     // if register server is not enabled, we disable all the configuration
     // controls for the server list
-    cbxCentServAddrType->setEnabled ( bCurSerListEnabled );
-    grbServerInfo->setEnabled ( bCurSerListEnabled );
+    cbxDirectoryType->setEnabled ( bIsRegistered );
+    grbServerInfo->setEnabled ( bIsRegistered );
 
     QString strStatus = svrRegStatusToString ( eSvrRegStatus );
 
@@ -683,7 +696,7 @@ void CServerDlg::UpdateGUIDependencies()
     {
     case SRS_BAD_ADDRESS:
     case SRS_TIME_OUT:
-    case SRS_CENTRAL_SVR_FULL:
+    case SRS_SERVER_LIST_FULL:
     case SRS_VERSION_TOO_OLD:
     case SRS_NOT_FULFILL_REQUIREMENTS:
         strStatus = "<font color=\"red\"><b>" + strStatus + "</b></font>";
@@ -702,7 +715,7 @@ void CServerDlg::UpdateGUIDependencies()
 
 void CServerDlg::UpdateSystemTrayIcon ( const bool bIsActive )
 {
-    if ( bSystemTrayIconAvaialbe )
+    if ( bSystemTrayIconAvailable )
     {
         if ( bIsActive )
         {
@@ -818,7 +831,7 @@ void CServerDlg::changeEvent ( QEvent* pEvent )
 {
     // if we have a system tray icon, we make the window invisible if it is
     // minimized
-    if ( bSystemTrayIconAvaialbe && ( pEvent->type() == QEvent::WindowStateChange ) )
+    if ( bSystemTrayIconAvailable && ( pEvent->type() == QEvent::WindowStateChange ) )
     {
         if ( isMinimized() )
         {
