@@ -1,5 +1,5 @@
 /******************************************************************************\
- * Copyright (c) 2004-2020
+ * Copyright (c) 2004-2022
  *
  * Author(s):
  *  Volker Fischer
@@ -270,6 +270,12 @@ void CClientSettings::ReadSettingsFromXML ( const QDomDocument& IniXMLDocument,
         eChannelSortType = static_cast<EChSortType> ( iValue );
     }
 
+    // own fader first sorting
+    if ( GetFlagIniSet ( IniXMLDocument, "client", "ownfaderfirst", bValue ) )
+    {
+        bOwnFaderFirst = bValue;
+    }
+
     // number of mixer panel rows
     if ( GetNumericIniSet ( IniXMLDocument, "client", "numrowsmixpan", 1, 8, iValue ) )
     {
@@ -405,6 +411,37 @@ void CClientSettings::ReadSettingsFromXML ( const QDomDocument& IniXMLDocument,
         pClient->SetGUIDesign ( static_cast<EGUIDesign> ( iValue ) );
     }
 
+    // MeterStyle
+    if ( GetNumericIniSet ( IniXMLDocument, "client", "meterstyle", 0, 4 /* MT_LED_ROUND_BIG */, iValue ) )
+    {
+        pClient->SetMeterStyle ( static_cast<EMeterStyle> ( iValue ) );
+    }
+    else
+    {
+        // if MeterStyle is not found in the ini, set it based on the GUI design
+        if ( GetNumericIniSet ( IniXMLDocument, "client", "guidesign", 0, 2 /* GD_SLIMFADER */, iValue ) )
+        {
+            switch ( iValue )
+            {
+            case GD_STANDARD:
+                pClient->SetMeterStyle ( MT_BAR_WIDE );
+                break;
+
+            case GD_ORIGINAL:
+                pClient->SetMeterStyle ( MT_LED_STRIPE );
+                break;
+
+            case GD_SLIMFADER:
+                pClient->SetMeterStyle ( MT_BAR_NARROW );
+                break;
+
+            default:
+                pClient->SetMeterStyle ( MT_LED_STRIPE );
+                break;
+            }
+        }
+    }
+
     // audio channels
     if ( GetNumericIniSet ( IniXMLDocument, "client", "audiochannels", 0, 2 /* CC_STEREO */, iValue ) )
     {
@@ -417,36 +454,47 @@ void CClientSettings::ReadSettingsFromXML ( const QDomDocument& IniXMLDocument,
         pClient->SetAudioQuality ( static_cast<EAudioQuality> ( iValue ) );
     }
 
+    // custom directories
     // clang-format off
 // TODO compatibility to old version (< 3.6.1)
-// NOTE that the strCurAddr and "check for empty" can be removed if compatibility mode is removed
-vstrCentralServerAddress[0] = GetIniSetting ( IniXMLDocument, "client", "centralservaddr" );
+QString strDirectoryAddress = GetIniSetting ( IniXMLDocument, "client", "centralservaddr", "" );
     // clang-format on
-
-    // directory server addresses
     for ( iIdx = 0; iIdx < MAX_NUM_SERVER_ADDR_ITEMS; iIdx++ )
     {
-        const QString strCurAddr = GetIniSetting ( IniXMLDocument, "client", QString ( "centralservaddr%1" ).arg ( iIdx ), "" );
-
-        if ( !strCurAddr.isEmpty() )
-        {
-            vstrCentralServerAddress[iIdx] = strCurAddr;
-        }
+        // clang-format off
+// TODO compatibility to old version (< 3.8.2)
+strDirectoryAddress = GetIniSetting ( IniXMLDocument, "client", QString ( "centralservaddr%1" ).arg ( iIdx ), strDirectoryAddress );
+        // clang-format on
+        vstrDirectoryAddress[iIdx] = GetIniSetting ( IniXMLDocument, "client", QString ( "directoryaddress%1" ).arg ( iIdx ), strDirectoryAddress );
+        strDirectoryAddress        = "";
     }
 
-    // directory server address type
-    if ( GetNumericIniSet ( IniXMLDocument, "client", "centservaddrtype", 0, static_cast<int> ( AT_CUSTOM ), iValue ) )
+    // directory type
+    // clang-format off
+// TODO compatibility to old version (<3.4.7)
+// only the case that "centralservaddr" was set in old ini must be considered
+if ( !vstrDirectoryAddress[0].isEmpty() && GetFlagIniSet ( IniXMLDocument, "client", "defcentservaddr", bValue ) && !bValue )
+{
+    eDirectoryType = AT_CUSTOM;
+}
+// TODO compatibility to old version (< 3.8.2)
+else if ( GetNumericIniSet ( IniXMLDocument, "client", "centservaddrtype", 0, static_cast<int> ( AT_CUSTOM ), iValue ) )
+{
+    eDirectoryType = static_cast<EDirectoryType> ( iValue );
+}
+    // clang-format on
+    else if ( GetNumericIniSet ( IniXMLDocument, "client", "directorytype", 0, static_cast<int> ( AT_CUSTOM ), iValue ) )
     {
-        eCentralServerAddressType = static_cast<ECSAddType> ( iValue );
+        eDirectoryType = static_cast<EDirectoryType> ( iValue );
     }
     else
     {
         // if no address type is given, choose one from the operating system locale
-        eCentralServerAddressType = AT_DEFAULT;
+        eDirectoryType = AT_DEFAULT;
     }
 
-    // custom directory server index
-    if ( ( eCentralServerAddressType == AT_CUSTOM ) &&
+    // custom directory index
+    if ( ( eDirectoryType == AT_CUSTOM ) &&
          GetNumericIniSet ( IniXMLDocument, "client", "customdirectoryindex", 0, MAX_NUM_SERVER_ADDR_ITEMS, iValue ) )
     {
         iCustomDirectoryIndex = iValue;
@@ -457,18 +505,6 @@ vstrCentralServerAddress[0] = GetIniSetting ( IniXMLDocument, "client", "central
         iCustomDirectoryIndex = 0;
     }
 
-    // clang-format off
-// TODO compatibility to old version (<3.4.7)
-if ( GetFlagIniSet ( IniXMLDocument, "client", "defcentservaddr", bValue ) )
-{
-    // only the case that manual was set in old ini must be considered
-    if ( !bValue )
-    {
-        eCentralServerAddressType = AT_CUSTOM;
-    }
-}
-    // clang-format on
-
     // window position of the main window
     vecWindowPosMain = FromBase64ToByteArray ( GetIniSetting ( IniXMLDocument, "client", "winposmain_base64" ) );
 
@@ -586,6 +622,9 @@ void CClientSettings::WriteSettingsToXML ( QDomDocument& IniXMLDocument )
     // fader channel sorting
     SetNumericIniSet ( IniXMLDocument, "client", "channelsort", static_cast<int> ( eChannelSortType ) );
 
+    // own fader first sorting
+    SetFlagIniSet ( IniXMLDocument, "client", "ownfaderfirst", bOwnFaderFirst );
+
     // number of mixer panel rows
     SetNumericIniSet ( IniXMLDocument, "client", "numrowsmixpan", iNumMixerPanelRows );
 
@@ -646,22 +685,25 @@ void CClientSettings::WriteSettingsToXML ( QDomDocument& IniXMLDocument )
     // GUI design
     SetNumericIniSet ( IniXMLDocument, "client", "guidesign", static_cast<int> ( pClient->GetGUIDesign() ) );
 
+    // MeterStyle
+    SetNumericIniSet ( IniXMLDocument, "client", "meterstyle", static_cast<int> ( pClient->GetMeterStyle() ) );
+
     // audio channels
     SetNumericIniSet ( IniXMLDocument, "client", "audiochannels", static_cast<int> ( pClient->GetAudioChannels() ) );
 
     // audio quality
     SetNumericIniSet ( IniXMLDocument, "client", "audioquality", static_cast<int> ( pClient->GetAudioQuality() ) );
 
-    // directory server addresses
+    // custom directories
     for ( iIdx = 0; iIdx < MAX_NUM_SERVER_ADDR_ITEMS; iIdx++ )
     {
-        PutIniSetting ( IniXMLDocument, "client", QString ( "centralservaddr%1" ).arg ( iIdx ), vstrCentralServerAddress[iIdx] );
+        PutIniSetting ( IniXMLDocument, "client", QString ( "directoryaddress%1" ).arg ( iIdx ), vstrDirectoryAddress[iIdx] );
     }
 
-    // directory server address type
-    SetNumericIniSet ( IniXMLDocument, "client", "centservaddrtype", static_cast<int> ( eCentralServerAddressType ) );
+    // directory type
+    SetNumericIniSet ( IniXMLDocument, "client", "directorytype", static_cast<int> ( eDirectoryType ) );
 
-    // custom directory server index
+    // custom directory index
     SetNumericIniSet ( IniXMLDocument, "client", "customdirectoryindex", iCustomDirectoryIndex );
 
     // window position of the main window
@@ -724,16 +766,26 @@ void CServerSettings::ReadSettingsFromXML ( const QDomDocument& IniXMLDocument,
     int  iValue;
     bool bValue;
 
-    // directory server address type (note that it is important
+    // window position of the main window
+    vecWindowPosMain = FromBase64ToByteArray ( GetIniSetting ( IniXMLDocument, "server", "winposmain_base64" ) );
+
+    // directory type (note that it is important
     // to set this setting prior to the "directory server address")
-    if ( GetNumericIniSet ( IniXMLDocument, "server", "centservaddrtype", 0, static_cast<int> ( AT_CUSTOM ), iValue ) )
+    // clang-format off
+// TODO compatibility to old version
+if ( GetNumericIniSet ( IniXMLDocument, "server", "centservaddrtype", 0, static_cast<int> ( AT_CUSTOM ), iValue ) )
+{
+    pServer->SetDirectoryType ( static_cast<EDirectoryType> ( iValue ) );
+}
+    // clang-format on
+    else if ( GetNumericIniSet ( IniXMLDocument, "server", "directorytype", 0, static_cast<int> ( AT_CUSTOM ), iValue ) )
     {
-        pServer->SetCentralServerAddressType ( static_cast<ECSAddType> ( iValue ) );
+        pServer->SetDirectoryType ( static_cast<EDirectoryType> ( iValue ) );
     }
     else
     {
         // if no address type is given, use the default directory server
-        pServer->SetCentralServerAddressType ( AT_DEFAULT );
+        pServer->SetDirectoryType ( AT_DEFAULT );
     }
 
     // clang-format off
@@ -743,7 +795,7 @@ if ( GetFlagIniSet ( IniXMLDocument, "server", "defcentservaddr", bValue ) )
     // only the case that manual was set in old ini must be considered
     if ( !bValue )
     {
-        pServer->SetCentralServerAddressType ( AT_CUSTOM );
+        pServer->SetDirectoryType ( AT_CUSTOM );
     }
 }
     // clang-format on
@@ -752,19 +804,20 @@ if ( GetFlagIniSet ( IniXMLDocument, "server", "defcentservaddr", bValue ) )
     {
         // directory server address (to be set after the "use default directory
         // server" address)
-        pServer->SetServerListCentralServerAddress ( GetIniSetting ( IniXMLDocument, "server", "centralservaddr" ) );
+        // clang-format off
+// TODO compatibility to old version
+QString directoryAddress = GetIniSetting ( IniXMLDocument, "server", "centralservaddr", "" );
+        // clang-format on
+        directoryAddress = GetIniSetting ( IniXMLDocument, "server", "directoryaddress", directoryAddress );
+        pServer->SetDirectoryAddress ( directoryAddress );
     }
 
     // server list enabled flag
     if ( GetFlagIniSet ( IniXMLDocument, "server", "servlistenabled", bValue ) )
     {
-        pServer->SetServerListEnabled ( bValue );
+        pServer->SetServerRegistered ( bValue );
     }
 
-    // language
-    strLanguage =
-        GetIniSetting ( IniXMLDocument, "server", "language", CLocale::FindSysLangTransFileName ( CLocale::GetAvailableTranslations() ).first );
-
     // name/city/country
     if ( !CommandLineOptions.contains ( "--serverinfo" ) )
     {
@@ -781,12 +834,12 @@ if ( GetFlagIniSet ( IniXMLDocument, "server", "defcentservaddr", bValue ) )
         }
     }
 
-    // start minimized on OS start
-    if ( !CommandLineOptions.contains ( "--startminimized" ) )
+    // norecord flag
+    if ( !CommandLineOptions.contains ( "--norecord" ) )
     {
-        if ( GetFlagIniSet ( IniXMLDocument, "server", "autostartmin", bValue ) )
+        if ( GetFlagIniSet ( IniXMLDocument, "server", "norecord", bValue ) )
         {
-            pServer->SetAutoRunMinimized ( bValue );
+            pServer->SetEnableRecording ( !bValue );
         }
     }
 
@@ -796,8 +849,9 @@ if ( GetFlagIniSet ( IniXMLDocument, "server", "defcentservaddr", bValue ) )
         pServer->SetWelcomeMessage ( FromBase64ToString ( GetIniSetting ( IniXMLDocument, "server", "welcome" ) ) );
     }
 
-    // window position of the main window
-    vecWindowPosMain = FromBase64ToByteArray ( GetIniSetting ( IniXMLDocument, "server", "winposmain_base64" ) );
+    // language
+    strLanguage =
+        GetIniSetting ( IniXMLDocument, "server", "language", CLocale::FindSysLangTransFileName ( CLocale::GetAvailableTranslations() ).first );
 
     // base recording directory
     if ( !CommandLineOptions.contains ( "--recording" ) )
@@ -805,12 +859,12 @@ if ( GetFlagIniSet ( IniXMLDocument, "server", "defcentservaddr", bValue ) )
         pServer->SetRecordingDir ( FromBase64ToString ( GetIniSetting ( IniXMLDocument, "server", "recordingdir_base64" ) ) );
     }
 
-    // norecord flag
-    if ( !CommandLineOptions.contains ( "--norecord" ) )
+    // start minimized on OS start
+    if ( !CommandLineOptions.contains ( "--startminimized" ) )
     {
-        if ( GetFlagIniSet ( IniXMLDocument, "server", "norecord", bValue ) )
+        if ( GetFlagIniSet ( IniXMLDocument, "server", "autostartmin", bValue ) )
         {
-            pServer->SetEnableRecording ( !bValue );
+            pServer->SetAutoRunMinimized ( bValue );
         }
     }
 
@@ -826,17 +880,17 @@ if ( GetFlagIniSet ( IniXMLDocument, "server", "defcentservaddr", bValue ) )
 
 void CServerSettings::WriteSettingsToXML ( QDomDocument& IniXMLDocument )
 {
-    // directory server address
-    PutIniSetting ( IniXMLDocument, "server", "centralservaddr", pServer->GetServerListCentralServerAddress() );
+    // window position of the main window
+    PutIniSetting ( IniXMLDocument, "server", "winposmain_base64", ToBase64 ( vecWindowPosMain ) );
 
-    // directory server address type
-    SetNumericIniSet ( IniXMLDocument, "server", "centservaddrtype", static_cast<int> ( pServer->GetCentralServerAddressType() ) );
+    // directory server address
+    PutIniSetting ( IniXMLDocument, "server", "directoryaddress", pServer->GetDirectoryAddress() );
+
+    // directory type
+    SetNumericIniSet ( IniXMLDocument, "server", "directorytype", static_cast<int> ( pServer->GetDirectoryType() ) );
 
     // server list enabled flag
-    SetFlagIniSet ( IniXMLDocument, "server", "servlistenabled", pServer->GetServerListEnabled() );
-
-    // language
-    PutIniSetting ( IniXMLDocument, "server", "language", strLanguage );
+    SetFlagIniSet ( IniXMLDocument, "server", "servlistenabled", pServer->GetServerRegistered() );
 
     // name
     PutIniSetting ( IniXMLDocument, "server", "name", pServer->GetServerName() );
@@ -847,20 +901,20 @@ void CServerSettings::WriteSettingsToXML ( QDomDocument& IniXMLDocument )
     // country
     SetNumericIniSet ( IniXMLDocument, "server", "country", static_cast<int> ( pServer->GetServerCountry() ) );
 
-    // start minimized on OS start
-    SetFlagIniSet ( IniXMLDocument, "server", "autostartmin", pServer->GetAutoRunMinimized() );
+    // norecord flag
+    SetFlagIniSet ( IniXMLDocument, "server", "norecord", pServer->GetDisableRecording() );
 
     // welcome message
     PutIniSetting ( IniXMLDocument, "server", "welcome", ToBase64 ( pServer->GetWelcomeMessage() ) );
 
-    // window position of the main window
-    PutIniSetting ( IniXMLDocument, "server", "winposmain_base64", ToBase64 ( vecWindowPosMain ) );
+    // language
+    PutIniSetting ( IniXMLDocument, "server", "language", strLanguage );
 
     // base recording directory
     PutIniSetting ( IniXMLDocument, "server", "recordingdir_base64", ToBase64 ( pServer->GetRecordingDir() ) );
 
-    // norecord flag
-    SetFlagIniSet ( IniXMLDocument, "server", "norecord", pServer->GetDisableRecording() );
+    // start minimized on OS start
+    SetFlagIniSet ( IniXMLDocument, "server", "autostartmin", pServer->GetAutoRunMinimized() );
 
     // delay panning
     SetFlagIniSet ( IniXMLDocument, "server", "delaypan", pServer->IsDelayPanningEnabled() );
