@@ -1,5 +1,5 @@
 /******************************************************************************\
- * Copyright (c) 2004-2020
+ * Copyright (c) 2004-2022
  *
  * Author(s):
  *  Volker Fischer
@@ -408,91 +408,93 @@ CAboutDlg::CAboutDlg ( QWidget* parent ) : CBaseDlg ( parent )
                         "</font></p>" );
 
     // libraries used by this compilation
-    txvLibraries->setText (
-        tr ( "This app uses the following libraries, resources or code snippets:" ) + "<br><p>" + tr ( "Qt cross-platform application framework" ) +
-        ", <i><a href=\"http://www.qt.io\">http://www.qt.io</a></i></p>"
-        "<p>Opus Interactive Audio Codec"
-        ", <i><a href=\"http://www.opus-codec.org\">http://www.opus-codec.org</a></i></p>"
-        "<p>" +
-        tr ( "Audio reverberation code by Perry R. Cook and Gary P. Scavone" ) +
-        ", 1995 - 2004, <i><a href=\"http://ccrma.stanford.edu/software/stk\">"
-        "The Synthesis ToolKit in C++ (STK)</a></i></p>"
-        "<p>" +
-        tr ( "Some pixmaps are from the" ) +
-        " Open Clip Art Library (OCAL), "
-        "<i><a href=\"http://openclipart.org\">http://openclipart.org</a></i></p>"
-        "<p>" +
-        tr ( "Country flag icons by Mark James" ) + ", <i><a href=\"http://www.famfamfam.com\">http://www.famfamfam.com</a></i></p>" );
+    txvLibraries->setText ( tr ( "This app uses the following libraries, resources or code snippets:" ) + "<br><p>" +
+                            tr ( "Qt cross-platform application framework" ) +
+                            ", <i><a href=\"https://www.qt.io\">https://www.qt.io</a></i></p>"
+                            "<p>Opus Interactive Audio Codec"
+                            ", <i><a href=\"https://www.opus-codec.org\">https://www.opus-codec.org</a></i></p>"
+                            "<p>" +
+                            tr ( "Audio reverberation code by Perry R. Cook and Gary P. Scavone" ) +
+                            ", 1995 - 2021, <i><a href=\"https://ccrma.stanford.edu/software/stk\">"
+                            "The Synthesis ToolKit in C++ (STK)</a></i></p>"
+                            "<p>" +
+                            tr ( "Some pixmaps are from the" ) +
+                            " Open Clip Art Library (OCAL), "
+                            "<i><a href=\"https://openclipart.org\">https://openclipart.org</a></i></p>"
+                            "<p>" +
+                            tr ( "Flag icons by Mark James" ) + ", <i><a href=\"http://www.famfamfam.com\">http://www.famfamfam.com</a></i></p>" );
 
     // contributors list
-    txvContributors->setText ( "<p>Volker Fischer (<a href=\"https://github.com/corrados\">corrados</a>)</p>"
-                               "<p>Peter L. Jones (<a href=\"https://github.com/pljones\">pljones</a>)</p>"
-                               "<p>Jonathan Baker-Bates (<a href=\"https://github.com/gilgongo\">gilgongo</a>)</p>"
-                               "<p>ann0see (<a href=\"https://github.com/ann0see\">ann0see</a>)</p>"
-                               "<p>Daniele Masato (<a href=\"https://github.com/doloopuntil\">doloopuntil</a>)</p>"
-                               "<p>Martin Schilde (<a href=\"https://github.com/geheimerEichkater\">geheimerEichkater</a>)</p>"
-                               "<p>Simon Tomlinson (<a href=\"https://github.com/sthenos\">sthenos</a>)</p>"
-                               "<p>Marc jr. Landolt (<a href=\"https://github.com/braindef\">braindef</a>)</p>"
-                               "<p>Olivier Humbert (<a href=\"https://github.com/trebmuh\">trebmuh</a>)</p>"
-                               "<p>Tarmo Johannes (<a href=\"https://github.com/tarmoj\">tarmoj</a>)</p>"
-                               "<p>mirabilos (<a href=\"https://github.com/mirabilos\">mirabilos</a>)</p>"
-                               "<p>Hector Martin (<a href=\"https://github.com/marcan\">marcan</a>)</p>"
-                               "<p>newlaurent62 (<a href=\"https://github.com/newlaurent62\">newlaurent62</a>)</p>"
-                               "<p>AronVietti (<a href=\"https://github.com/AronVietti\">AronVietti</a>)</p>"
-                               "<p>Emlyn Bolton (<a href=\"https://github.com/emlynmac\">emlynmac</a>)</p>"
-                               "<p>Jos van den Oever (<a href=\"https://github.com/vandenoever\">vandenoever</a>)</p>"
-                               "<p>Tormod Volden (<a href=\"https://github.com/tormodvolden\">tormodvolden</a>)</p>"
-                               "<p>Alberstein8 (<a href=\"https://github.com/Alberstein8\">Alberstein8</a>)</p>"
-                               "<p>Gauthier Fleutot Östervall (<a href=\"https://github.com/fleutot\">fleutot</a>)</p>"
-                               "<p>Tony Mountifield (<a href=\"https://github.com/softins\">softins</a>)</p>"
-                               "<p>HPS (<a href=\"https://github.com/hselasky\">hselasky</a>)</p>"
-                               "<p>Stanislas Michalak (<a href=\"https://github.com/stanislas-m\">stanislas-m</a>)</p>"
-                               "<p>JP Cimalando (<a href=\"https://github.com/jpcima\">jpcima</a>)</p>"
-                               "<p>Adam Sampson (<a href=\"https://github.com/atsampson\">atsampson</a>)</p>"
-                               "<p>Jakob Jarmar (<a href=\"https://github.com/jarmar\">jarmar</a>)</p>"
-                               "<p>Stefan Weil (<a href=\"https://github.com/stweil\">stweil</a>)</p>"
-                               "<p>Nils Brederlow (<a href=\"https://github.com/dingodoppelt\">dingodoppelt</a>)</p>"
-                               "<p>Sebastian Krzyszkowiak (<a href=\"https://github.com/dos1\">dos1</a>)</p>"
-                               "<p>Bryan Flamig (<a href=\"https://github.com/bflamig\">bflamig</a>)</p>"
-                               "<p>Kris Raney (<a href=\"https://github.com/kraney\">kraney</a>)</p>"
-                               "<p>dszgit (<a href=\"https://github.com/dszgit\">dszgit</a>)</p>"
-                               "<p>nefarius2001 (<a href=\"https://github.com/nefarius2001\">nefarius2001</a>)</p>"
-                               "<p>jc-Rosichini (<a href=\"https://github.com/jc-Rosichini\">jc-Rosichini</a>)</p>"
-                               "<p>Julian Santander (<a href=\"https://github.com/j-santander\">j-santander</a>)</p>"
-                               "<p>chigkim (<a href=\"https://github.com/chigkim\">chigkim</a>)</p>"
-                               "<p>Bodo (<a href=\"https://github.com/bomm\">bomm</a>)</p>"
-                               "<p>Christian Hoffmann (<a href=\"https://github.com/hoffie\">hoffie</a>)</p>"
-                               "<p>jp8 (<a href=\"https://github.com/jp8\">jp8</a>)</p>"
-                               "<p>James (<a href=\"https://github.com/jdrage\">jdrage</a>)</p>"
-                               "<p>ranfdev (<a href=\"https://github.com/ranfdev\">ranfdev</a>)</p>"
-                               "<p>bspeer (<a href=\"https://github.com/bspeer\">bspeer</a>)</p>"
-                               "<p>Martin Passing (<a href=\"https://github.com/passing\">passing</a>)</p>"
-                               "<p>DonC (<a href=\"https://github.com/dcorson-ticino-com\">dcorson-ticino-com</a>)</p>"
-                               "<p>David Kastrup (<a href=\"https://github.com/dakhubgit\">dakhubgit</a>)</p>"
-                               "<p>Jordan Lum (<a href=\"https://github.com/mulyaj\">mulyaj</a>)</p>"
-                               "<p>Noam Postavsky (<a href=\"https://github.com/npostavs\">npostavs</a>)</p>"
-                               "<p>David Savinkoff (<a href=\"https://github.com/DavidSavinkoff\">DavidSavinkoff</a>)</p>"
-                               "<p>Johannes Brauers (<a href=\"https://github.com/JohannesBrx\">JohannesBrx</a>)</p>"
-                               "<p>Henk De Groot (<a href=\"https://github.com/henkdegroot\">henkdegroot</a>)</p>"
-                               "<p>Ferenc Wágner (<a href=\"https://github.com/wferi\">wferi</a>)</p>"
-                               "<p>Martin Kaistra (<a href=\"https://github.com/djfun\">djfun</a>)</p>"
-                               "<p>Burkhard Volkemer (<a href=\"https://github.com/buv\">buv</a>)</p>"
-                               "<p>Magnus Groß (<a href=\"https://github.com/vimpostor\">vimpostor</a>)</p>"
-                               "<p>Julien Taverna (<a href=\"https://github.com/jujudusud\">jujudusud</a>)</p>"
-                               "<p>Detlef Hennings (<a href=\"https://github.com/DetlefHennings\">DetlefHennings</a>)</p>"
-                               "<p>drummer1154 (<a href=\"https://github.com/drummer1154\">drummer1154</a>)</p>"
-                               "<p>helgeerbe (<a href=\"https://github.com/helgeerbe\">helgeerbe</a>)</p>"
-                               "<p>Hk1020 (<a href=\"https://github.com/Hk1020\">Hk1020</a>)</p>"
-                               "<p>Jeroen van Veldhuizen (<a href=\"https://github.com/jeroenvv\">jeroenvv</a>)</p>"
-                               "<p>Reinhard (<a href=\"https://github.com/reinhardwh\">reinhardwh</a>)</p>"
-                               "<p>Stefan Menzel (<a href=\"https://github.com/menzels\">menzels</a>)</p>"
-                               "<p>Dau Huy Ngoc (<a href=\"https://github.com/ngocdh\">ngocdh</a>)</p>"
-                               "<p>Jiri Popek (<a href=\"https://github.com/jardous\">jardous</a>)</p>"
-                               "<p>Gary Wang (<a href=\"https://github.com/BLumia\">BLumia</a>)</p>"
-                               "<br>" +
-                               tr ( "For details on the contributions check out the " ) +
-                               "<a href=\"https://github.com/jamulussoftware/jamulus/graphs/contributors\">" + tr ( "Github Contributors list" ) +
-                               "</a>." );
+    txvContributors->setText (
+        "<p>Volker Fischer (<a href=\"https://github.com/corrados\">corrados</a>)</p>"
+        "<p>Peter L. Jones (<a href=\"https://github.com/pljones\">pljones</a>)</p>"
+        "<p>Jonathan Baker-Bates (<a href=\"https://github.com/gilgongo\">gilgongo</a>)</p>"
+        "<p>ann0see (<a href=\"https://github.com/ann0see\">ann0see</a>)</p>"
+        "<p>Daniele Masato (<a href=\"https://github.com/doloopuntil\">doloopuntil</a>)</p>"
+        "<p>Martin Schilde (<a href=\"https://github.com/geheimerEichkater\">geheimerEichkater</a>)</p>"
+        "<p>Simon Tomlinson (<a href=\"https://github.com/sthenos\">sthenos</a>)</p>"
+        "<p>Marc jr. Landolt (<a href=\"https://github.com/braindef\">braindef</a>)</p>"
+        "<p>Olivier Humbert (<a href=\"https://github.com/trebmuh\">trebmuh</a>)</p>"
+        "<p>Tarmo Johannes (<a href=\"https://github.com/tarmoj\">tarmoj</a>)</p>"
+        "<p>mirabilos (<a href=\"https://github.com/mirabilos\">mirabilos</a>)</p>"
+        "<p>Hector Martin (<a href=\"https://github.com/marcan\">marcan</a>)</p>"
+        "<p>newlaurent62 (<a href=\"https://github.com/newlaurent62\">newlaurent62</a>)</p>"
+        "<p>AronVietti (<a href=\"https://github.com/AronVietti\">AronVietti</a>)</p>"
+        "<p>Emlyn Bolton (<a href=\"https://github.com/emlynmac\">emlynmac</a>)</p>"
+        "<p>Jos van den Oever (<a href=\"https://github.com/vandenoever\">vandenoever</a>)</p>"
+        "<p>Tormod Volden (<a href=\"https://github.com/tormodvolden\">tormodvolden</a>)</p>"
+        "<p>Alberstein8 (<a href=\"https://github.com/Alberstein8\">Alberstein8</a>)</p>"
+        "<p>Gauthier Fleutot Östervall (<a href=\"https://github.com/fleutot\">fleutot</a>)</p>"
+        "<p>Tony Mountifield (<a href=\"https://github.com/softins\">softins</a>)</p>"
+        "<p>HPS (<a href=\"https://github.com/hselasky\">hselasky</a>)</p>"
+        "<p>Stanislas Michalak (<a href=\"https://github.com/stanislas-m\">stanislas-m</a>)</p>"
+        "<p>JP Cimalando (<a href=\"https://github.com/jpcima\">jpcima</a>)</p>"
+        "<p>Adam Sampson (<a href=\"https://github.com/atsampson\">atsampson</a>)</p>"
+        "<p>Jakob Jarmar (<a href=\"https://github.com/jarmar\">jarmar</a>)</p>"
+        "<p>Stefan Weil (<a href=\"https://github.com/stweil\">stweil</a>)</p>"
+        "<p>Nils Brederlow (<a href=\"https://github.com/dingodoppelt\">dingodoppelt</a>)</p>"
+        "<p>Sebastian Krzyszkowiak (<a href=\"https://github.com/dos1\">dos1</a>)</p>"
+        "<p>Bryan Flamig (<a href=\"https://github.com/bflamig\">bflamig</a>)</p>"
+        "<p>Kris Raney (<a href=\"https://github.com/kraney\">kraney</a>)</p>"
+        "<p>dszgit (<a href=\"https://github.com/dszgit\">dszgit</a>)</p>"
+        "<p>nefarius2001 (<a href=\"https://github.com/nefarius2001\">nefarius2001</a>)</p>"
+        "<p>jc-Rosichini (<a href=\"https://github.com/jc-Rosichini\">jc-Rosichini</a>)</p>"
+        "<p>Julian Santander (<a href=\"https://github.com/j-santander\">j-santander</a>)</p>"
+        "<p>chigkim (<a href=\"https://github.com/chigkim\">chigkim</a>)</p>"
+        "<p>Bodo (<a href=\"https://github.com/bomm\">bomm</a>)</p>"
+        "<p>Christian Hoffmann (<a href=\"https://github.com/hoffie\">hoffie</a>)</p>"
+        "<p>jp8 (<a href=\"https://github.com/jp8\">jp8</a>)</p>"
+        "<p>James (<a href=\"https://github.com/jdrage\">jdrage</a>)</p>"
+        "<p>ranfdev (<a href=\"https://github.com/ranfdev\">ranfdev</a>)</p>"
+        "<p>bspeer (<a href=\"https://github.com/bspeer\">bspeer</a>)</p>"
+        "<p>Martin Passing (<a href=\"https://github.com/passing\">passing</a>)</p>"
+        "<p>DonC (<a href=\"https://github.com/dcorson-ticino-com\">dcorson-ticino-com</a>)</p>"
+        "<p>David Kastrup (<a href=\"https://github.com/dakhubgit\">dakhubgit</a>)</p>"
+        "<p>Jordan Lum (<a href=\"https://github.com/mulyaj\">mulyaj</a>)</p>"
+        "<p>Noam Postavsky (<a href=\"https://github.com/npostavs\">npostavs</a>)</p>"
+        "<p>David Savinkoff (<a href=\"https://github.com/DavidSavinkoff\">DavidSavinkoff</a>)</p>"
+        "<p>Johannes Brauers (<a href=\"https://github.com/JohannesBrx\">JohannesBrx</a>)</p>"
+        "<p>Henk De Groot (<a href=\"https://github.com/henkdegroot\">henkdegroot</a>)</p>"
+        "<p>Ferenc Wágner (<a href=\"https://github.com/wferi\">wferi</a>)</p>"
+        "<p>Martin Kaistra (<a href=\"https://github.com/djfun\">djfun</a>)</p>"
+        "<p>Burkhard Volkemer (<a href=\"https://github.com/buv\">buv</a>)</p>"
+        "<p>Magnus Groß (<a href=\"https://github.com/vimpostor\">vimpostor</a>)</p>"
+        "<p>Julien Taverna (<a href=\"https://github.com/jujudusud\">jujudusud</a>)</p>"
+        "<p>Detlef Hennings (<a href=\"https://github.com/DetlefHennings\">DetlefHennings</a>)</p>"
+        "<p>drummer1154 (<a href=\"https://github.com/drummer1154\">drummer1154</a>)</p>"
+        "<p>helgeerbe (<a href=\"https://github.com/helgeerbe\">helgeerbe</a>)</p>"
+        "<p>Hk1020 (<a href=\"https://github.com/Hk1020\">Hk1020</a>)</p>"
+        "<p>Jeroen van Veldhuizen (<a href=\"https://github.com/jeroenvv\">jeroenvv</a>)</p>"
+        "<p>Reinhard (<a href=\"https://github.com/reinhardwh\">reinhardwh</a>)</p>"
+        "<p>Stefan Menzel (<a href=\"https://github.com/menzels\">menzels</a>)</p>"
+        "<p>Dau Huy Ngoc (<a href=\"https://github.com/ngocdh\">ngocdh</a>)</p>"
+        "<p>Jiri Popek (<a href=\"https://github.com/jardous\">jardous</a>)</p>"
+        "<p>Gary Wang (<a href=\"https://github.com/BLumia\">BLumia</a>)</p>"
+        "<p>RobyDati (<a href=\"https://github.com/RobyDati\">RobyDati</a>)</p>"
+        "<p>Rob-NY (<a href=\"https://github.com/Rob-NY\">Rob-NY</a>)</p>"
+        "<br>" +
+        tr ( "For details on the contributions check out the %1" )
+            .arg ( "<a href=\"https://github.com/jamulussoftware/jamulus/graphs/contributors\">" + tr ( "Github Contributors list" ) + "</a>." ) );
 
     // translators
     txvTranslation->setText ( "<p><b>" + tr ( "Spanish" ) +
@@ -543,7 +545,7 @@ CAboutDlg::CAboutDlg ( QWidget* parent ) : CBaseDlg ( parent )
     lblVersion->setText ( GetVersionAndNameStr() );
 
     // set window title
-    setWindowTitle ( tr ( "About " ) + APP_NAME );
+    setWindowTitle ( tr ( "About %1" ).arg ( APP_NAME ) );
 }
 
 // Licence dialog --------------------------------------------------------------
@@ -666,6 +668,29 @@ void CLanguageComboBox::OnLanguageActivated ( int iLanguageIdx )
         emit LanguageChanged ( itemData ( iLanguageIdx ).toString() );
     }
 }
+
+QString TruncateString ( QString str, int position )
+{
+    QTextBoundaryFinder tbfString ( QTextBoundaryFinder::Grapheme, str );
+
+    tbfString.setPosition ( position );
+    if ( !tbfString.isAtBoundary() )
+    {
+        tbfString.toPreviousBoundary();
+        position = tbfString.position();
+    }
+    return str.left ( position );
+}
+
+QSize CMinimumStackedLayout::sizeHint() const
+{
+    // always use the size of the currently visible widget:
+    if ( currentWidget() )
+    {
+        return currentWidget()->sizeHint();
+    }
+    return QStackedLayout::sizeHint();
+}
 #endif
 
 /******************************************************************************\
@@ -691,25 +716,28 @@ bool NetworkUtil::ParseNetworkAddress ( QString strAddress, CHostAddress& HostAd
     // hostname:port
     // (where addr4or6 is a literal IPv4 or IPv6 address, and addr4 is a literal IPv4 address
 
-    bool    bLiteralAddr = false;
-    QRegExp rx1 ( "^\\[([^]]*)\\](?::(\\d+))?$" ); // [addr4or6] or [addr4or6]:port
-    QRegExp rx2 ( "^([^:]*)(?::(\\d+))?$" );       // addr4 or addr4:port or host or host:port
+    bool               bLiteralAddr = false;
+    QRegularExpression rx1 ( "^\\[([^]]*)\\](?::(\\d+))?$" ); // [addr4or6] or [addr4or6]:port
+    QRegularExpression rx2 ( "^([^:]*)(?::(\\d+))?$" );       // addr4 or addr4:port or host or host:port
 
     QString strPort;
 
+    QRegularExpressionMatch rx1match = rx1.match ( strAddress );
+    QRegularExpressionMatch rx2match = rx2.match ( strAddress );
+
     // parse input address with rx1 and rx2 in turn, capturing address/host and port
-    if ( rx1.indexIn ( strAddress ) == 0 )
+    if ( rx1match.capturedStart() == 0 )
     {
         // literal address within []
-        strAddress   = rx1.cap ( 1 );
-        strPort      = rx1.cap ( 2 );
+        strAddress   = rx1match.captured ( 1 );
+        strPort      = rx1match.captured ( 2 );
         bLiteralAddr = true; // don't allow hostname within []
     }
-    else if ( rx2.indexIn ( strAddress ) == 0 )
+    else if ( rx2match.capturedStart() == 0 )
     {
         // hostname or IPv4 address
-        strAddress = rx2.cap ( 1 );
-        strPort    = rx2.cap ( 2 );
+        strAddress = rx2match.captured ( 1 );
+        strPort    = rx2match.captured ( 2 );
     }
     else
     {
@@ -829,12 +857,12 @@ CHostAddress NetworkUtil::GetLocalAddress6()
     }
 }
 
-QString NetworkUtil::GetCentralServerAddress ( const ECSAddType eCentralServerAddressType, const QString& strCentralServerAddress )
+QString NetworkUtil::GetDirectoryAddress ( const EDirectoryType eDirectoryType, const QString& strDirectoryAddress )
 {
-    switch ( eCentralServerAddressType )
+    switch ( eDirectoryType )
     {
     case AT_CUSTOM:
-        return strCentralServerAddress;
+        return strDirectoryAddress;
     case AT_ANY_GENRE2:
         return CENTSERV_ANY_GENRE2;
     case AT_ANY_GENRE3:
@@ -925,6 +953,44 @@ int CHostAddress::Compare ( const CHostAddress& other ) const
     return thisAddr < otherAddr ? -1 : thisAddr > otherAddr ? 1 : 0;
 }
 
+QString CHostAddress::toString ( const EStringMode eStringMode ) const
+{
+    QString strReturn = InetAddr.toString();
+
+    // special case: for local host address, we do not replace the last byte
+    if ( ( ( eStringMode == SM_IP_NO_LAST_BYTE ) || ( eStringMode == SM_IP_NO_LAST_BYTE_PORT ) ) &&
+         ( InetAddr != QHostAddress ( QHostAddress::LocalHost ) ) && ( InetAddr != QHostAddress ( QHostAddress::LocalHostIPv6 ) ) )
+    {
+        // replace last part by an "x"
+        if ( strReturn.contains ( "." ) )
+        {
+            // IPv4 or IPv4-mapped:
+            strReturn = strReturn.section ( ".", 0, -2 ) + ".x";
+        }
+        else
+        {
+            // IPv6
+            strReturn = strReturn.section ( ":", 0, -2 ) + ":x";
+        }
+    }
+
+    if ( ( eStringMode == SM_IP_PORT ) || ( eStringMode == SM_IP_NO_LAST_BYTE_PORT ) )
+    {
+        // add port number after a colon
+        if ( strReturn.contains ( "." ) )
+        {
+            strReturn += ":" + QString().setNum ( iPort );
+        }
+        else
+        {
+            // enclose pure IPv6 address in [ ] before adding port, to avoid ambiguity
+            strReturn = "[" + strReturn + "]:" + QString().setNum ( iPort );
+        }
+    }
+
+    return strReturn;
+}
+
 // Instrument picture data base ------------------------------------------------
 CVector<CInstPictures::CInstPictProps>& CInstPictures::GetTable ( const bool bReGenerateTable )
 {
@@ -1083,6 +1149,12 @@ CVector<CInstPictures::CInstPictProps>& CInstPictures::GetTable ( const bool bRe
         vecDataBase.Add ( CInstPictProps ( QCoreApplication::translate ( "CClientSettingsDlg", "Rapping" ),
                                            ":/png/instr/res/instruments/rapping.png",
                                            IC_OTHER_INSTRUMENT ) );
+        vecDataBase.Add ( CInstPictProps ( QCoreApplication::translate ( "CClientSettingsDlg", "Vibraphone" ),
+                                           ":/png/instr/res/instruments/vibraphone.png",
+                                           IC_PERCUSSION_INSTRUMENT ) );
+        vecDataBase.Add ( CInstPictProps ( QCoreApplication::translate ( "CClientSettingsDlg", "Conductor" ),
+                                           ":/png/instr/res/instruments/conductor.png",
+                                           IC_OTHER_INSTRUMENT ) );
 
         // now the table is initialized
         TableIsInitialized = true;
@@ -1833,23 +1905,27 @@ void CLocale::LoadTranslation ( const QString strLanguage, QCoreApplication* pAp
 /******************************************************************************\
 * Global Functions Implementation                                              *
 \******************************************************************************/
-QString GetVersionAndNameStr ( const bool bWithHtml )
+QString GetVersionAndNameStr ( const bool bDisplayInGui )
 {
     QString strVersionText = "";
 
     // name, short description and GPL hint
-    if ( bWithHtml )
+    if ( bDisplayInGui )
     {
         strVersionText += "<b>";
     }
     else
     {
+#ifdef _WIN32
+        // start with newline to print nice in windows command prompt
+        strVersionText += "\n";
+#endif
         strVersionText += " *** ";
     }
 
     strVersionText += APP_NAME + QCoreApplication::tr ( ", Version " ) + VERSION;
 
-    if ( bWithHtml )
+    if ( bDisplayInGui )
     {
         strVersionText += "</b><br>";
     }
@@ -1858,13 +1934,51 @@ QString GetVersionAndNameStr ( const bool bWithHtml )
         strVersionText += "\n *** ";
     }
 
-    if ( !bWithHtml )
+    if ( !bDisplayInGui )
     {
         strVersionText += QCoreApplication::tr ( "Internet Jam Session Software" );
         strVersionText += "\n *** ";
     }
 
-    strVersionText += QCoreApplication::tr ( "Released under the GNU General Public License (GPL)" );
+    strVersionText += QCoreApplication::tr ( "Released under the GNU General Public License version 2 or later (GPLv2)" );
+
+    if ( !bDisplayInGui )
+    {
+        // additional text to show in console output
+        strVersionText += "\n *** ";
+        strVersionText += "<https://www.gnu.org/licenses/old-licenses/gpl-2.0.html>";
+        strVersionText += "\n *** ";
+        strVersionText += "\n *** ";
+        strVersionText += QCoreApplication::tr ( "This program is free software; you can redistribute it and/or modify it under" );
+        strVersionText += "\n *** ";
+        strVersionText += QCoreApplication::tr ( "the terms of the GNU General Public License as published by the Free Software" );
+        strVersionText += "\n *** ";
+        strVersionText += QCoreApplication::tr ( "Foundation; either version 2 of the License, or (at your option) any later version." );
+        strVersionText += "\n *** ";
+        strVersionText += QCoreApplication::tr ( "There is NO WARRANTY, to the extent permitted by law." );
+        strVersionText += "\n *** ";
+        strVersionText += "\n *** ";
+        strVersionText += QCoreApplication::tr ( "Using the following libraries, resources or code snippets:" );
+        strVersionText += "\n *** ";
+        strVersionText += QCoreApplication::tr ( "Qt framework " ) + QT_VERSION_STR;
+        strVersionText += " <https://doc.qt.io/qt-5/lgpl.html>";
+        strVersionText += "\n *** ";
+        strVersionText += QCoreApplication::tr ( "Opus Interactive Audio Codec" );
+        strVersionText += " <https://www.opus-codec.org>";
+        strVersionText += "\n *** ";
+        strVersionText += QCoreApplication::tr ( "Audio reverberation code by Perry R. Cook and Gary P. Scavone" );
+        strVersionText += " <https://ccrma.stanford.edu/software/stk>";
+        strVersionText += "\n *** ";
+        strVersionText += QCoreApplication::tr ( "Some pixmaps are from the Open Clip Art Library (OCAL)" );
+        strVersionText += " <https://openclipart.org>";
+        strVersionText += "\n *** ";
+        strVersionText += QCoreApplication::tr ( "Flag icons by Mark James" );
+        strVersionText += " <http://www.famfamfam.com>";
+        strVersionText += "\n *** ";
+        strVersionText += "\n *** ";
+        strVersionText += QCoreApplication::tr ( "Copyright (C) 2005-2022 The Jamulus Development Team" );
+        strVersionText += "\n";
+    }
 
     return strVersionText;
 }
